@@ -738,7 +738,9 @@ _gdata_service_send_message (GDataService *self, SoupMessage *message, GCancella
 	 *
 	 * Note that we have to re-process the message with the authoriser so that its authorisation headers get updated after the refresh
 	 * (bgo#653535). */
-	if (message->status_code == SOUP_STATUS_UNAUTHORIZED) {
+	if (message->status_code == SOUP_STATUS_UNAUTHORIZED ||
+	    message->status_code == SOUP_STATUS_FORBIDDEN ||
+	    message->status_code == SOUP_STATUS_NOT_FOUND) {
 		GDataAuthorizer *authorizer = self->priv->authorizer;
 
 		if (authorizer != NULL && gdata_authorizer_refresh_authorization (authorizer, cancellable, NULL) == TRUE) {
@@ -1813,7 +1815,7 @@ gdata_service_delete_entry (GDataService *self, GDataAuthorizationDomain *domain
 		/* Redirect error or cancelled */
 		g_object_unref (message);
 		return FALSE;
-	} else if (status != SOUP_STATUS_OK) {
+	} else if (status != SOUP_STATUS_OK && status != SOUP_STATUS_NO_CONTENT) {
 		/* Error */
 		GDataServiceClass *service_klass = GDATA_SERVICE_GET_CLASS (self);
 		g_assert (service_klass->parse_error_response != NULL);
